/**
 * app.js
 * 
 * Application level JavaScript functions. All developers are required to write comments
 * for all new code since we now minify all inhouse Javascript files during our release process.
 * 
 * There are 3 areas in this file:
 * 
 * 1. Major component related functions. Functions directly related to major components
 * 	such as jstree, tinymce etc.
 * 2. Application generic functions. Functions that can be reused regardless of feature.
 * 3. Feature specific functions. Functions that are only used in one feature. Try not to
 * 	have too many of these functions and write generic code that goes to area #2 above.
 *
 * @author $Author: suppakit $
 * @version $Id: app.js,v 1.267 2012/05/24 13:26:09 suppakit Exp $
 * @copyright Copyright (c) 2012, Tiller Software Co., Ltd.
*/

/***************************** Major component related functions ****************************/

function newLocation(url){
	window.location=url;
	return false;
}

function goHome(urlpath) {
	if ( typeof(urlpath) == 'undefined' ) {
		urlpath = '';
	}
	window.location=appHomeUrl + urlpath;
	return false;
}

function changeMenuHeight() {
	menudiv = document.getElementById('menu');
	menudiv.style.height=window.innerHeight - 145;
}

function init_tinymce(enableAsciisvg, default_plaintext_paste) {
	if ( typeof(tinyMCE) !== 'undefined' ) {
		var asciisvg = '';
		if ( enableAsciisvg === true ) {
			asciisvg = ',asciisvg';
		}
		if ( !isBoolean(default_plaintext_paste) ) {
			default_plaintext_paste = true;
		}
		
		var init_settings = {
			mode : "textareas",
		   theme : "advanced",
		   theme_advanced_buttons1 : "fontselect,fontsizeselect,bold,italic,underline,strikethrough,separator,sub,sup,separator,cut,copy,paste,undo,redo,pastetext,pasteword,selectall",
		   //The alignment buttons are in conflict with the application so took them out. Using BR tag instead of P tag also disables the alignment function.
		    //theme_advanced_buttons2 : "justifyleft,justifycenter,justifyright,justifyfull,separator,numlist,bullist,outdent,indent,separator,forecolor,backcolor,separator,hr,link,unlink,image,table,code,separator,asciimath,asciimathcharmap,asciisvg",
		   theme_advanced_buttons2 : "numlist,bullist,outdent,indent,separator,forecolor,backcolor,separator,hr,link,unlink,image,table,code,separator,asciimath,asciimathcharmap" + asciisvg,
		   theme_advanced_buttons3 : "",
		   theme_advanced_toolbar_location : "top",
		   theme_advanced_toolbar_align : "left",
		   theme_advanced_statusbar_location : "bottom",
		   plugins : 'paste,asciimath,asciisvg,table,inlinepopups',
		   //fix new line <p> to <br/>
		   force_br_newlines : true,
	      force_p_newlines : false,
	      forced_root_block : '', // Needed for 3.x
	       //set font family to tinymce
	      theme_advanced_fonts : "Arial=arial,helvetica,sans-serif,Courier New=courier new,courier,monospace,Georgia=georgia,times new roman,times,serif," +
	        							  "Tahoma=tahoma,arial,helvetica,sans-serif,Times=times new roman,times,serif,Verdana - Default=verdana,arial,helvetica,sans-serif",
		    //fix select font size
		   font_size_style_values : "8,9,10,11,12,14,16,24,36",
		   theme_advanced_font_sizes : "8px,9px,10px,11px,12px,14px,16px,24px,36px",
		   theme_advanced_runtime_fontsize : true,
		   
		   paste_create_paragraphs : false,
			paste_create_linebreaks : true,
			paste_use_dialog : true,
			paste_auto_cleanup_on_paste : true,
			paste_convert_middot_lists : true,
			// paste_retain_style_properties default is "none" but old coder put 'true' that cause an error in Mac (Firefox/Safari)
			// now we change to "all" to let user retain their paste style
			// source: http://www.tinymce.com/wiki.php/Plugin:paste
			paste_retain_style_properties : "all",
			//paste_unindented_list_class : "unindentedList",
			paste_convert_headers_to_strong : true,
			/*
			paste_use_dialog : false,
			paste_auto_cleanup_on_paste : true,
			paste_convert_headers_to_strong : false,
			paste_strip_class_attributes : "all",
			paste_remove_spans : true,
			paste_remove_styles : true,
			paste_retain_style_properties : "none",
			*/
			/*
			paste_text_sticky : true,
			setup : function(ed) {
						  ed.onInit.add(function(ed) {
						  ed.pasteAsPlainText = true;
					  }); },
			*/
			handle_event_callback : "cms_tinymce_event",
			AScgiloc : AScgiloc,
		   //This one is special since every graph will save (to DB) the path to d.svg in the include folder
		   //Have to make it static and always in include and do not use app_include_path.
		   ASdloc : appHomeUrl + "include/js/tiny_mce/plugins/asciisvg/js/d.svg",
		   content_css : appIncludePath + "css/style_tinymce.css",
		   // Turn on spell check.
		   gecko_spellcheck : true,
		   // Allows the textarea box to be resized.
		   theme_advanced_resizing : true,
		   // Don't use cookie so auto resize is turned off.
		   theme_advanced_resizing_use_cookie : false
		};
		
		if ( default_plaintext_paste ) {
			init_settings.paste_text_sticky = true;
			init_settings.setup = function(ed) {
											  ed.onInit.add(function(ed) {
											  ed.pasteAsPlainText = true;
										  }); };
		}
		
		tinyMCE.init(init_settings);
	}
}

// For hiding the tinymce math plugin. Do not use this for other purposes.
/*
function hiddenOBJ(objid) {
	if ( !isString(objid) ) {
		objid = 'mathplayer';
	}
	hideObj('#'+objid);
}
*/

var pdfWaitHtml=false;
function LoadPdfPage(url, pdf, divid) {
	var obj = document.getElementById(divid);
	if ( isObject(obj) ) {
		if ( isString(pdfWaitHtml) )  {
			obj.innerHTML = pdfWaitHtml;
		}
		ajaxGetpage(divid, url+pdf, true);
	}
	return false;
}

///// Begining of session event related code /////

// DO NOT MODIFY ANY CODE IN THIS OBJECT ELSE YOU CAN BREAK THE SESSION CHECKS WITHOUT KNOWING.
//
// This is a sigleton but not implemented in a typical singleton pattern. You always get the singleton
// object with "new" but it will give you the same object. This should be called only once per session
// and it prevents the code to break if someone calls it twice. This is our TODCM Jscript singleton pattern.
// Judging from how Jscript handles objects, I think our pattern is way better than the typical singleton pattern.
// It is simple and less code required for the class. It can create many empty objects but I think it is actually
// faster than the typical singlton pattern implemented using Jscript. Will do some benchmarking when I have time...
// Always think outside of the box!
// We don't always need this object so we don't want to always load the object for every session.
var cms_session_class = function() {
	if ( typeof(cms_session_class.singleton) !== 'undefined' ) {
		return cms_session_class.singleton;
	}
	// So we always have the first object and you can referecne this by the class name (the orginal object in the top window scope).
	// All TODCM singletons have to contain this property.
	cms_session_class.singleton = this;
	///////////////////////////////////////////////////////////////////////////////////////////
	// All the following objet variables and functions are private and can not be accessed outside of this object.
	var that = this;
	var url_update = appHomeUrl + 'session_update';
	var url_check = appHomeUrl + 'session_update/check';
	var config = {
		// The reference to the update funtion in this object form outside.
		GLOBAL_UPDATE_METHOD : 'cms_session_class.singleton.update',
		URL_UPDATE : url_update,
		URL_CHECK :	url_check,
		JS_CODE_SESSION_UPDATE : "ajaxPostform('','" + url_update + "','',true,false)",
		JS_CODE_SESSION_CHECK : "ajaxPostform('','" + url_check + "','',true,false,false,false,['X-Cms-Skip-Session-Update','1'])",
		// For immediate update after receiving a key stroke or mouse click the time for the next update if the first one failed.
		// The update retry would not stop until server access is avaiable again.
		UPDATE_RETRY_TIME : 60*1000,
		// Timer value for the session check or session update. Override by PHP.
		system_session_timer : 5*60*1000,
		// If inactive for more than this time update on the first key/mouse event. Real value is system_session_timer*3.
		system_immediate_update_time : 15*60*1000,
		// Keeps track of the current interval timer call.
		timer_handle : null,
		// Keep track of the current retry timer (setTiemout).
		update_retry_timer_handle : null,
		// Only ready if the home page calls update() with the init params.
		ready_state : false,
		// Total idel time without ajax calls (server access).
		user_ajax_inactive_time : 0,
		// To check for session or now, a successful ajax call besides the session check would reset this.
		needs_checking : true
	};
		
	var private_obj = new function() {
		var that = this;
		// Reset after a successful update or outside ajax call.
		this.reset = function() {
			config.user_ajax_inactive_time = 0;
			config.needs_checking = false;
		};
		
		// Check for valid interval timer handle.
		this.is_valid_timer = function() {
			return (config.timer_handle !== null && !isNaN(config.timer_handle));
		};
		
		// Clears the current timer event and sets the hanle to null.
		// Only called for logout redirect.
		this.clear_timer = function() {
			if ( that.is_valid_timer() ) {
				clearInterval(config.timer_handle);
			}
			config.timer_handle = null;
		};
		
		// Starts the timer event.
		this.start_timer = function(wait_time) {
			if ( that.is_valid_timer() ) {
				return;
			}
			if ( !isInteger(wait_time) ) {
				wait_time = config.system_session_timer;
			}
			this.count = 0;
			while ( !that.is_valid_timer() && this.count++ < 10 ) {
				config.timer_handle = setInterval(config.GLOBAL_UPDATE_METHOD + '(' + wait_time + ')', wait_time);
			}
			if ( this.count >= 10 ) {
				alert(gGeneralJavasriptError);
			}
		};
		
		// Checks for valid session from the server. Does not do update.
		this.check_session = function() {
			if ( config.needs_checking ) {
				eval(config.JS_CODE_SESSION_CHECK);
			}
			else {
				config.needs_checking = true;
			}
		};
	};
	// End of private_obj
	
	///////////////////////////////////////////////////////////////////////////////////////////
	// All the following are public functions that can be called from outside of this object.
	
	// Callback function for ajaxPostform.
	// We changed all the session update and check to async call and this is the only place that deals with the real logic.
	// This function only process local URLs so it is save to use the ajax library with external sites.
	// url - The requested URL
	// request_object - The whole httpRequest object.
	this.request_result = function(url, request_object) {
		if ( !isString(url) || !isObject(request_object) || typeof(request_object.responseText) === 'undefined' ||
				config.ready_state !== true || url.indexOf(appHomeUrl) < 0 ) {
			return;
		}
		if ( url !== config.URL_CHECK && url !== config.URL_UPDATE ) {
			// Browser sent request to server and session should get updated/checked properly so reset.
			private_obj.reset();
			return;
		}
		if ( url == config.URL_UPDATE ) {
			// This could be the first non-timer call but just reset it even if it is not necessary.
			config.update_retry_timer_handle = null;
		}
		if ( request_object.responseText === ajaxSuccess ) {
			if ( url != config.URL_CHECK ) {
				private_obj.reset();
			}
		}
		else if ( request_object.responseText === ajaxFailed ) {
			// Redirect to home page regardless what url it is from since there is no session.
			private_obj.clear_timer();
			window.location = appHomeUrl + 'login/logout';
		}
		else if ( url == config.URL_UPDATE ) {
			// We failed to update so spawn a one time event timer to try update again.
			that.update_session();
		}
		// If web server is down then it just keep checking the session or kepp trying to update.
		// The web page would stay unchnaged unless the user close or refresh.
	};
	
	// Update the session. Only called from a mouse or key event if user has been inactive for a long time.
	// update_now - true for normal update, false - retry when previous update is not succvessful.
	this.update_session = function(update_now) {
		if ( config.ready_state !== true ) {
			return;
		}
		if ( update_now === true ) {
			eval(config.JS_CODE_SESSION_UPDATE);
		}
		else {
			// This is a delayed update called form request_result.
			if ( config.update_retry_timer_handle === null ) {
				config.update_retry_timer_handle = setTimeout(config.JS_CODE_SESSION_UPDATE, config.UPDATE_RETRY_TIME);
			}
		}
	};
	
	// Event function to make sure session gets updated on the first browser activity after a long
	// period of inactivity.
	this.browser_event = function() {
		// No need to check for ready state since user_ajax_inactive_time is always 0 if state not ready.
		// This function gets run on every key stroke and mouse click so has to be efficient.
		if ( config.user_ajax_inactive_time > config.system_immediate_update_time ) {
			if ( config.ready_state !== true ) {
				return;
			}
			that.update_session(true);
		}
	};
	
	// timer_value - The current timer value in ms, this is how long it waits/sleeps.
	//					  Can also be the value for system_session_timer during initialization.
	// init_params - To initialize or not.
	this.update = function(timer_value, init_params) {
		if ( !isInteger(timer_value) || timer_value < 1000 ) {
			timer_value = config.system_session_timer;
		}
		if ( init_params === true ) {
			// Make sure we have all the global variables we need.
			if ( typeof(ajaxFailed) === 'undefined' || typeof(ajaxSuccess) === 'undefined' ||
					typeof(appHomeUrl) === 'undefined' ) {
				var msg;
				if ( typeof(gGeneralJavasriptError) === 'undefined' ) {
					msg = gGeneralJavasriptError;
				}
				else {
					// This is really bad.
					msg = 'Javascript error in function cms_session_class.update.';
				}
				alert(msg);
				return;
			}
			// The first time will set the mouse and key events and populate the params.
			/* Very old stuff and not needed any more.
			if( document.captureEvents && Event.CLICK ) {
				document.captureEvents(Event.CLICK);
			}
			if( document.captureEvents && Event.KEYUP ) {
				document.captureEvents( Event.KEYUP );
			}
			*/
			document.onmouseup = this.browser_event;
			document.onkeyup = this.browser_event;
		
			// Check for session for every 5 minutes.
			config.system_session_timer = timer_value;
			// Immediate update on the first key/mouse event after 15 minutes of inactivity.
			config.system_immediate_update_time = timer_value * 3;
			config.ready_state = true;
			// Kick start the timer event.
			private_obj.start_timer(config.system_session_timer);
			return;
		}
		
		if ( config.ready_state !== true ) {
			return;
		}
		config.user_ajax_inactive_time += timer_value;
		private_obj.check_session();
	};
	
	// return the curren object and stores it in global variable cms_session.
	// return this;
};
// End of cms_session_class.

// For the resource popup iframe window.
function cms_tinymce_event(e) {
	// Do not change the order of these condtions.
	if ( e.type === 'keyup' || e.type === 'mouseup' ) {
		if ( typeof(parent.cms_session_class.singleton) !== 'undefined' ) {
			parent.cms_session_class.singleton.browser_event();
		}
	}
}

// For survey only for now and implemented as a faux-singleton. It is loaded on-demand.
// It does create an empty object every time called with "new" but always used the first object instead.
// But we really just call "new" only once for the survey page so this works really well.
var basic_session_check = function(wrapper, controller_function) {
	if ( typeof(basic_session_check.singleton) !== 'undefined' ) {
		return basic_session_check.singleton;
	}
	basic_session_check.singleton = this;
	var that = this;
	this.wrapper = wrapper;
	this.ready = false;
	this.controller_function = controller_function;
	
	if ( !isString(this.controller_function) ) {
		this.controller_function = 'check';
	}
	
	this.callback = function(url, request_object) {
		if ( !isString(url) || !isObject(request_object) || typeof(request_object.responseText) === 'undefined' ) {
			return;
		}
		if ( request_object.responseText == ajaxFailed ) {
			window.location = surveyHomeUrl;
		}
	};
		
	this.check = function() {
		ajaxPostform('', appHomeUrl + 'session_update/' + that.controller_function,'',
						 true,false,that.wrapper,['X-Cms-Skip-Session-Update','1']);
	};
	
	this.process = function(url, request_object) {
		if ( that.ready !== true ) {
			return;
		}
		if ( isString(url) && isObject(request_object) ) {
			this.callback(url, request_object);
		}
		else {
			this.check();
		}
	};
	
	if ( that.ready === false ) {
			// You can only run this once.
		that.ready = true;
		setInterval(this.wrapper + '()', 5*60*1000);
	}
};

// Session check wrapper to load the basic_session_check class, start the timer and receive callback.
// This is a generic implementation and can be used on any page.
// URL param can be the controller function during class loading.
// The default CI controller function is check.
function basic_session_check_wrapper(url, request_object) {
	if ( typeof(this.myobj) === 'undefined' ) {
		this.myobj = new basic_session_check('basic_session_check_wrapper', url);
		return;
	}
	this.myobj.process(url, request_object);
}

///// End of session event related code /////

// Attach (onKeyPress) this event function to a text field and it will disable the enter key.
function noEnterKey(event) {
	var keycode=0;
	if ( typeof(window.event) !== 'undefined' ) {
		keycode = window.event.keyCode;
	}
	else if ( typeof(event) !== 'undefined' ) {
		keycode = event.which;
	}
	if (keycode == 13) {
		return false;
	}
}

function openBrowserWindow(url, width, height, window_name, scrollbars, menubar) {
	if ( !isString(url) ) {
		return false;
	}
	if ( !isInteger(width) ) {
		width=1000;
	}
	if ( !isInteger(height) ) {
		height=750;
	}
	if ( !isString(window_name) ) {
		window_name = 'pdf'+new Date().getTime();
	}
	var top = (screen.height-height)/2 - 60;
	if ( top < 0 ) {
		top = 0;
	}
	var left = (screen.width-width)/2;
	if ( left < 0 ) {
		left = 0;
	}
	var option = 'status=no,toolbar=no,location=no,resizable=yes';
	if ( scrollbars === true ) {
		option = option + ',scrollbars=yes';
	}
	if ( menubar === true ) {
		option = option + ',menubar=yes';
	}
	else {
		option = option + ',menubar=no';
	}
	option = option + ',top=' + top + ',left=' + left + ',width=' + width + ',height=' + height;
	var new_winobj = window.open(url,window_name,option);
	new_winobj.focus();
	return false;
}

function init_jstree(treename, tree_html, other_trees) {
	$(function () {
		$('#'+treename).jstree({
			'core' : { 'initially_open' : [ 'root' ] },
			'html_data' : {
			  'data' : tree_html,
			  'ajax' : {
			  		'url' : function (node){
						var current_url = $(node).children('a').attr('name');
			  			return current_url;
			  		}
			  	}
			},
			'themes' : {
				'theme' : 'classic',
				'url' : appIncludePath + 'js/jstree/themes/classic/style.css'
         },
         'types' : {
         	'types' :{
         		//leaf nodes (nodes have no children)
         		'file' : {'icon' : {'image' : app_image_folder + 'page.gif'}},
         		'editicon_type' : {'icon' : {'image' : app_image_folder + 'edit.gif'}},
         		'copyicon_type' : {'icon' : {'image' : app_image_folder + 'copy.gif'}},
         		'mytree_icon_type' : {'icon' : {'image' : app_image_folder + 'mycourse.gif'}}
         	}
         },
			'plugins' : [ 'themes', 'html_data', 'cookies', 'types', 'ui']
		});
		$('#'+treename+' a').live('click', function(e) {
        $('#'+treename).jstree('toggle_node', this);
        $(other_trees).jstree('deselect_all');
        return false;
		});
	});
}

function toggleTreePanel(init) {
	if ( typeof(this.panel_idname) == 'undefined' ) {
        this.panel_idname = '#left_panel';
        this.hide_button = '#hide_panel_button';
        this.show_button = '#show_panel_button';
   }
	if ( init === true ) {
		hideObj(this.show_button);
		showObj(this.hide_button);
		showObj(this.panel_idname);
	}
	else {
		ShowOrHideobj(this.hide_button);
		ShowOrHideobj(this.show_button);
		ShowOrHideobj(this.panel_idname);
	}
	return false;
}

/*
 * Handles the header buttons.
 * url - Required url.
 * divid - Div for the url. If a string is not supplied then menu div is used.
 * content_url - The second url that is for the page_content div. A url string or true to show the logo.
 */
function site_director(url, divid, content_url, show_tree) {
	if ( !isString(url) ) {
		goHome('home');
		return false;
	}
	if ( !isString(divid) ) {
		divid = 'menu';
	}
	if ( typeof(content_url) == 'undefined' || content_url === true ) {
		content_url = 'home/logo';
	}
	url = appHomeUrl + url;
	ajaxGetpage(divid, url, true);
	if ( isString(content_url) ) {
		ajaxGetpage('page_content', appHomeUrl+content_url, true);
	}
	if ( typeof(show_tree) === 'undefined' || show_tree === true ) {
		toggleTreePanel(true);
	}
	else {
		toggleTreePanel(false);
	}
	return false;
}

function doMenuTree() {
	var button = document.getElementById('switch_tree_button');
	if ( showDept==true ) {
		showDept=false;
		shrinkMenuDiv('dept_tree');
		expandMenuDiv('grade_tree');
		if ( isObject(button) ) {
			button.value = deptButton;
		}
	}
	else {
		showDept=true;
		shrinkMenuDiv('grade_tree');
		expandMenuDiv('dept_tree');
		if ( isObject(button) ) {
			button.value = gradeButton;
		}
	}
	return false;
}

// This is the resource upload/text popup window from the template engine submit.
function submit_resource_iframe(url, formname, stageurl, divid, closediv) {
	if ( !isString(url) || !isString(formname) ) {
		return false;
	}
	var obj = document.getElementById('text1');
	if ( isObject(obj) && typeof(tinyMCE) !== 'undefined' ) {
		var str = tinyMCE.get('text1').getContent();
		// fix default font style & font size
		str = str.replace('<span style="font-family: verdana,arial,helvetica,sans-serif;"><span style="font-size: 11px;">&nbsp;</span></span>','');
		str = str.replace('<span style="font-family: verdana,arial,helvetica,sans-serif;"></span>','');
		obj.value = str;
	}
	if ( !isString(closediv) ) {
		closediv = 'resource';
	}
	var ret = ajaxPostform('', url, formname, false);
	if ( ret != false  || typeof ret == 'string' ) {
		if ( isString(divid) && isString(stageurl) ) {
			parent.ajaxGetpage(divid, stageurl);
		}
		parent.closeDhtmlWindow(closediv);
	}
	return false;
}

/*
// Debugging function
function printObject(obj) {
	var str = '';
	for (prop in obj) {
		str+= "****" + prop + ' : ' + obj[prop] + ' <br /><br /> ';
	}
	document.write (str);
}
*/

/**************************** Application generic functions ****************************/

// TODO: Rewrite shrinkDiv and expandDiv to not use showDiv() and hideDiv().
// This the only palce still needs the old style div hide and show code.
function shrinkDiv(name, margin) {
	var divobj = document.getElementById(name);
	hideDiv(name);
	if ( isObject(divobj) && typeof(divobj.style) !== 'undefined' ) {
		divobj.style.height = '1px'; //0px won't work in IE7
		divobj.style.width = '1px';
		divobj.style.overflow = 'hidden';
		if (typeof(margin) != 'undefined' && typeof(divobj.style.margin) != 'undefined' ) {
			divobj.style.margin = margin;
		}
	}
}

function expandDiv(name, margin) {
	var divobj = document.getElementById(name);
	if ( isObject(divobj) && typeof(divobj.style) !== 'undefined' ) {
		divobj.style.height = 'auto';
		divobj.style.width = 'auto';
		divobj.style.overflow = 'auto';
		if ( typeof(margin) != 'undefined' && typeof(divobj.style.margin) != 'undefined' ) {
			divobj.style.margin = margin;
		}
	}
	showDiv(name);
}

//This will work for any checkboxes on any form.
//The name_pattern (default is gradeid_) will separate multiple groups of checkboxes.
function allowOneCheckBox(checkBox,name_pattern) {
	var theform = checkBox.form;
	var elementname,elementtype,matched_str;
	if ( typeof(name_pattern) == 'undefined' ) {
		name_pattern='gradeid_';
	}
	var regexobj=new RegExp(name_pattern,'gi');
	for(var i=0; i < theform.elements.length; i++) {
		elementname=theform.elements[i].name;
		if ( typeof(elementname) == 'undefined' || elementname == '' )
			elementname = theform.elements[i].id;
		if ( typeof(elementname) == 'undefined' || elementname == '' )
			continue;
		elementtype = theform.elements[i].tagName.toLowerCase();
		if (elementtype == 'input' && theform.elements[i].type == 'checkbox' && theform.elements[i] != checkBox) {
			matched_str=elementname.match(regexobj);
			if ( matched_str == name_pattern ) {
				theform.elements[i].checked=false;
			}
		}
	}
	return true;
}

function downloadWindow(url) {
	var obj = document.getElementById('hiddeniframesystemdownload');
	if ( !isObject(obj) ) {
		//Only create a iframe once for the duration of the session
		obj = document.createElement("iframe");
		obj.setAttribute('id', 'hiddeniframesystemdownload');
		document.body.appendChild(obj);
		hideObj('#hiddeniframesystemdownload');
	}
	if ( isObject(obj) ) {
		obj.src = url;
	}
	else {
		//Fall back to old style browser window mode if somehow iframe does not work
		mywindow = window.open(url,'download','width=1,height=1');
		mywindow.blur();
		mywindow.moveTo(600,500);
	}
	return false;
}

function cancelInput(divid, url) {
	var ret = confirm(cancelInputMessage);
	if ( ret ) {
		ajaxGetpage(divid, url, true);
	}
	return false;
}

function cancelIframe(divid) {
	var ret = confirm(parent.cancelInputMessage);
	if ( ret ) {
		parent.closeDhtmlWindow(divid);
	}
	return false;
}

function reset_page(obj, url) {
	var ret = confirm(parent.cancelInputMessage);
	if ( ret ) {
		refresh_page(obj, url);
	}
	return false;
}

function updateDivConfirm(divid, url, msg) {
	var ret = confirm(msg);
	if ( ret ) {
		ajaxGetpage(divid, url, false);
	}
	return ret;
}

function cancelDhtml(divid) {
	var ret = confirm(parent.cancelInputMessage);
	if ( ret ) {
		closeDhtmlWindow(divid);
	}
	return false;
}

function submitDhtml(url, formname, refreshurl, divid, dhtmlname) {
	var ret = ajaxPostform('', url, formname, false);
	// The controller in url has to print success or no output in order to run the stage/refresh url.
	if ( ret===true || ret==='' || ret===ajaxSuccess ) {
		if ( isString(refreshurl) && isString(divid) ) {
			updateContainer(divid, refreshurl);
		}
		if ( typeof dhtmlname == 'undefined' ) {
			// Not sure where this 'select' is?
			dhtmlname = 'select';
		}
		closeDhtmlWindow(dhtmlname);
	}
	return false;
}

function updateTarget(url, formname, divid, closediv) {
	if ( ajaxPostform(divid, url, formname, false) ) {
		closeDhtmlWindow(closediv);
	}
	return false;
}

function delTarget(url, divid, msg) {
	if ( confirm(msg) ) {
		ajaxGetpage(divid, url, false);
	}
	return false;
}

function writeSpan(objid, msg) {
	var obj = document.getElementById(objid);
	if ( obj != 'undefined' ) {
		obj.innerHTML = msg;
	}
}

// Renders a flash chart.
function print_flashchart(swfurl,divid,width,height,dataurl) {
	var newurl = dataurl + '/' + new Date().getTime();
	var encodedurl = encodeURIComponent(newurl);
	//wmode: opaque, transparent, window
	//swfobject.embedSWF(swfurl,divid,width,height,"9.0.0","expressInstall.swf",{"data-file":encodedurl,"wmode":"opaque"});
	swfobject.embedSWF(swfurl,divid,width,height,"9.0.0","expressInstall.swf",{"data-file":encodedurl});
}

// Prints a flash chart in a new popup window.
function flashchart_window(url,title,width,height,divid,formname,chartdata) {
	if ( !isArray(chartdata) ) {
		return false;
	}
	ajaxClipboard(true);
	var rethtml=ajaxPostform('', url, formname, false);
	if ( rethtml != false ) {
		var valid_flash_param=true;
		var ajax_data = ajaxClipboard(true);
		
		if ( isArray(ajax_data) && ajax_data.length > 0 ) {
			// 0 - true to print flah, false to skip
			// 1 - win width, required
			// 2 - window height, required
			// 3 - chart width, set to 0 if not used.
			// 4 - flash chart height, set to 0 if not used
			valid_flash_param = ajax_data[0];
			if ( ajax_data.length > 2 ) {
				width = ajax_data[1];
				height = ajax_data[2];
			}
			if ( valid_flash_param && ajax_data.length > 4 ) {
				chartdata[2] = ajax_data[3];
				chartdata[3] = ajax_data[4];
				var diff = height - chartdata[3];
				var screen_offset = 110;
				if ( typeof screen != 'undefined' && typeof screen.availHeight != 'undefined' &&
					 screen.availHeight > 300 ) {
					if ( screen.availHeight-screen_offset-diff < chartdata[3] ) {
						chartdata[3] = screen.availHeight-screen_offset-diff;
						// dhtmlwindow code will reduce the height.
						height = screen.availHeight;
					}
				}
			}
		}
		// Don't alter the window width even if browser window is smaller.
		create_dhtmlxwindow.alter_width_flag = false;
		newDhtmlWindow_text(title, width, height, divid, rethtml);
		if ( valid_flash_param ) {
			// chartdata[4] is data url, chartdata[3] is chart height, chartdata[2] is chart width
			print_flashchart(chartdata[0],chartdata[1],chartdata[2],chartdata[3],chartdata[4]);
		}
	}
	return false;
}

//Function to hide parent window whenever child window is shown on the screen
function prepareDhxwinFlipDisplay(obj, parentid) {
	if ( isDhtmlxObject(obj) ) {
		obj.cms_parent_dhxwinid = parentid;
		obj.attachEvent('onClose', 'unhideParentDhxwin');
		obj.attachEvent('onParkUp', 'unhideParentDhxwin');
		obj.attachEvent('onParkDown', 'hideParentDhxwin');
		obj.attachEvent('onShow', 'hideParentDhxwin');
		obj.attachEvent('onHide', 'unhideParentDhxwin');
	}
}

function hideParentDhxwin(winobj) {
	if ( isDhtmlxObject(winobj) && typeof winobj.cms_parent_dhxwinid != 'undefined' ) {
		hideDhtmlWindow(winobj.cms_parent_dhxwinid);
	}
	return true;
}

function unhideParentDhxwin(winobj) {
	if ( isDhtmlxObject(winobj) && typeof winobj.cms_parent_dhxwinid != 'undefined' ) {
		showDhtmlWindow(winobj.cms_parent_dhxwinid);
	}
	return true;
}

//for open and post data to newDhtml
function ajaxPostWindow(url,title,width,height,divid,formname) {
	var rethtml=ajaxPostform('', url, formname, false);
	if ( isString(rethtml) ) {
		newDhtmlWindow_text(title, width, height, divid, rethtml);
	}
	return false;
}

//checkbox checkd to textbox by parseInt +1 when checked and -1 when unchecked
function remove_flag(obj,flag_name) {
	if (obj != undefined ) {
		removeflag = document.getElementById(flag_name);
		if (removeflag != undefined ) {
			if (removeflag.value=='')
				removeflag.value = 0;
			if (obj.checked == 1)
				removeflag.value = parseInt(removeflag.value)+1;
			else
				removeflag.value = parseInt(removeflag.value)-1;
		}
	}
}

//update_div is for Dhtmlx window, set it to '' if not using it
//notwin_div - normal div and ignore param if not using
//*** THIS FUNCTION IS DEPRICATED. USE updateContainer() INSTEAD ***
function updateWindow(url, formname, title, update_div, notwin_div) {
	if (typeof notwin_div == 'undefined' || notwin_div == '' || notwin_div == false) {
		var obj = getDhtmlWindowById(update_div);
		if (obj != null ) {
			var rethtml = ajaxPostform('', url, formname, false);
			winobjAttachHtml(obj, rethtml);
		}
	}
	else {
		var obj = document.getElementById(notwin_div);
		if (obj != undefined ) {
			ajaxPostform(notwin_div, url, formname, true);
		}
	}
	return false;
}

//Container can be a DIV or DhtmlWindow reference/name. The code will figure out which one and update properly.
//This makes updateWindow() obsolete
function updateContainer(container, url, formname) {
	if ( !isString(container) || !isString(url) ) {
		alert('updateContainer(): ' + gGeneralJavasriptError);
		return false;
	}
	if ( !isString(formname) ) {
		formname = '';
	}
	var obj = getDhtmlWindowById(container);
	if ( isDhtmlxObject(obj) ) {
		var rethtml = ajaxPostform('', url, formname, false);
		if ( isString(rethtml) ) {
			winobjAttachHtml(obj, rethtml);
		}
		return false;
	}
	obj = document.getElementById(container);
	if ( isObject(obj) ) {
		ajaxPostform(container, url, formname, true);
		return false;
	}
	alert('updateContainer(): ' + gGeneralJavasriptError);
	return false;
}

/* Just give a name of obj with css selector syntax
 * for example
 * id name - Prepend # to id name : '#idname'
 * class name = Prepend '.' to class name : '.classname'
 * paragraph tag = 'p'
 */
// toggle function will display or hide. If hiding obj will show and showing obj will hide
function ShowOrHideobj(objname){
	$(objname).toggle();
}

function showObj(objname){
	$(objname).show();
}

function hideObj(objname){
	$(objname).hide();
}

function disable_button(buttonid) {
	var buttonobj = document.getElementById(buttonid);
	if ( isObject(buttonobj) && (buttonobj.className == 'btn' || buttonobj.className == 'btnhov') ) {
		if ( typeof buttonobj.disabled != 'undefined' ) {
			buttonobj.disabled=true;
		}
		if ( typeof buttonobj.className != 'undefined' ) {
			buttonobj.className = 'dis';
		}
	}
}

function enable_button(buttonid) {
	var buttonobj = document.getElementById(buttonid);
	if ( isObject(buttonobj) && (buttonobj.className == 'btn' ||
		  buttonobj.className == 'btnhov' || buttonobj.className == 'dis') ) {
		if ( typeof buttonobj.disabled != 'undefined' ) {
			buttonobj.disabled=false;
		}
		// Some buttons are hardcoded with the color for disabling effect so need this to clean the style.
		// Normally, buttons should not contain any style so this should not have any ill effect.
		if ( typeof buttonobj.style.cssText != 'undefined' ) {
			buttonobj.style.cssText='';
		}
		if ( typeof buttonobj.className != 'undefined' ) {
			buttonobj.className = 'btn';
		}
	}
}

//Post data and fade object.
function ajaxPostFade(url, id, formname, divid, second, refreshtree, do_confirm) {
	if ( do_confirm === true && !confirm(cancelInputMessage) ) {
		return;
	}
	if ( refreshtree == undefined ) {
		refreshtree = true;
	}
	if ( !isString(divid)) {
		divid = 'page_content';
	}
	if ( ajaxPostform(divid, url, formname, false) ) {
		fadeObject(id, second);
		if ( refreshtree === true ) {
			refresh_menutree();
		}
	}
}

function fadeObject(id, second) {
	var obj = document.getElementById(id);
	if ( !isObject(obj) ) {
		return false;
	}

	// Check "second" parameter
	// if it not set or not an interger and can not convert to interger then use default.
	if ( !isInteger(second) ) {
		// Default is 5 second
		second = 5;
	}

	var hideObject = function() {
		// this is jquery do a slideUp animation and hide object.
		$(obj).slideUp('slow');
	};
	setTimeout(hideObject,second*1000);
}

// Check to see if all radio buttons are checked on a form.
function checked_all_radios(formname) {
	var theform = document.forms[formname];
	var checked_array=new Array(0);
	var elementtype;
	for(var i=0; i < theform.elements.length; i++) {
		elementname = theform.elements[i].name;
		if ( typeof(elementname) == 'undefined' || elementname == '' )
			elementname = theform.elements[i].id;
		if ( typeof(elementname) == 'undefined' || elementname == '' )
			continue;
		elementtype = theform.elements[i].tagName.toLowerCase();
		if (elementtype == 'input' && theform.elements[i].type == 'radio') {
			if ( checked_array[elementname] === undefined ) {
				checked_array[elementname] = theform.elements[i].checked;
			}
			else if ( theform.elements[i].checked ) {
				checked_array[elementname] = true;
			}
		}
	}
	var retcode = true;
	for (var i in checked_array) {
		if ( !checked_array[i] ) {
			retcode = false;
			break;
		}
	}
	return retcode;
}

// Generic function to run a url and then do a refresh if update was successful.
// The controller function has to print the proper ajax success message in order for this to work.
function update_refresh(updateurl, div, refreshurl) {
	if ( isString(updateurl) && isString(div) && isString(refreshurl) ) {
		var ret = ajaxGetpage(false, updateurl, false);
		// true and '' are here to make sure old code doesn't break.
		if ( ret === ajaxSuccess || ret === true || ret === '' ) {
			ajaxGetpage(div, refreshurl);
		}
	}
	return false;
}

// Make the dhtnlxwindow position stay when scrolling within the window. Without this, the
// browser window will scroll up.
function scroll_popup(anchor_id) {
	if ( !isString(anchor_id) ) {
		return true;
	}
	var obj = document.getElementById(anchor_id);
	if ( isObject(obj) && typeof(obj.scrollIntoView) !== 'undefined' ) {
		var offsetY, offsetX, diffY;
		if(!window.pageYOffset) {
			if(!(document.documentElement.scrollTop == 0)) {
				offsetY = document.documentElement.scrollTop;
			}
			else {
				offsetY = document.body.scrollTop;
			}
		}
		else {
			offsetY = window.pageYOffset;
		}
		
		obj.scrollIntoView();
		
		if(!window.pageYOffset) {
			if(!(document.documentElement.scrollTop == 0)) {
				offsetX = document.documentElement.scrollLeft;
			}
			else {
				offsetX = document.body.scrollLeft;
			}
		}
		else {
			offsetX = window.pageXOffset;
		}
		window.scrollTo(offsetX,offsetY);
		return false;
	}
	return true;
}

// Mainly for the tree menu to fire up a new link and scroll the browser window to the top.
function pagescroll(divid, url) {
	ajaxGetpage(divid, url);
	window.scrollTo(0,0);
}

/**************************** Feature specific functions ****************************/
/*
function LoadUnitPage(url,divid) {
	ajaxGetpage(divid, url, false);
   return false;
}
*/
function LoadUnitEditPage(url,divid,courseid) {
	var retcode = ajaxGetpage(divid, url, false);
	if ( retcode ) {
		refresh_menutree();
	}
   return false;
}

function updateUnit(formname, url, courseid) {
	if ( ajaxPostform('page_content', url, formname, false) ){
		refresh_menutree();
		return true;
	}
	return false;
}

function undoUnitEdit(url, courseid, msg) {
	if ( confirm(msg) ) {
		if ( ajaxPostform('page_content', url, '', false) ){
			refresh_menutree();
			window.scrollTo(0,0);
		}
	}
}

//for refresh menu tree
function confirmUnit(url, courseids, msg) {
	if ( confirm(msg) ) {
		if ( ajaxPostform('page_content', url, '', false) ) {
			refresh_menutree();
			window.scrollTo(0,0);
		}
	}
}

function removeUnit(url, courseid, msg) {
	if ( confirm(msg) ) {
		if ( ajaxPostform('page_content', url, '', false) ){
			refresh_menutree();
		}
	}
}

function refresh_menutree() {
	// get name list of menutrees from globalvars
	var trees = gMenutreenames;
	if ( typeof trees != 'undefined' ) {
		$(trees).jstree('refresh');
	}
	totalunit_refresh();
	return false;
}

function shrinkMenuDiv(name) {
	hideObj('#'+name);
}

function expandMenuDiv(name) {
	showObj('#'+name);
}

function setNewCourseOwner(divid) {
	index=document.editorsel_form.editor_sel.selectedIndex;
	if ( index >= 0 ) {
		name = document.editorsel_form.editor_sel.options[index].text;
		id = document.editorsel_form.editor_sel.options[index].value;
		document.getElementById('editornames').innerHTML = name;
		document.editcouresdes_form.editorid.value = id;
		closeDhtmlWindow('changeteacher_div');
	}
	else {
		printErrorWindow('Please select a user.');
	}
	return false;
}

//java script for Integrated Unit, Unified Unit
function setNewUnitOwner(url_refresh, formname, closediv, lang_del,flag_name) {
	ask_id = 0;
	removeflag = document.getElementById(flag_name);
	if (removeflag != undefined ) {
		ask_id = parseInt(removeflag.value);
	}
	if (ask_id > 0) { //remove
		var answer = confirm(lang_del);
	    if (answer) {
	    	ajaxPostform('page_content', url_refresh, formname, true);
			closeDhtmlWindow(closediv);
	    }
	} else { // normal add
		ajaxPostform('page_content', url_refresh, formname, true);
		closeDhtmlWindow(closediv);
	}
	return false;
}

//java script for Integrated Unit, Unified Unit
function setEditUnitOwner( url_check_mode, url_insert, url_delete, url_refresh, formname, lang_del, closediv) {
	var rethtml = ajaxPostform('', url_check_mode, formname, false);
	var str = rethtml.split("|");
	if (str != undefined) {
		var ask_id = str[0];
		//var ref_id = str[1];
		if (ask_id==1) {
			var answer = confirm(lang_del);
		    if (answer) {
		    	ajaxPostform('', url_insert, formname, false);
		    	ajaxPostform('', url_delete, formname, false);
		    	ajaxPostform('page_content', url_refresh, formname, false);
		    	//refresh_menutree(ref_id);
		    }
		}
		else { // normal add
			ajaxPostform('', url_insert, formname, false);
			ajaxPostform('page_content', url_refresh, formname, false);
		}
		refresh_menutree();
		closeDhtmlWindow(closediv);
	}
	return false;
}

//java script for Integrated Unit, Unified Unit  // multi-select and check duplicated
function show_select(obj, targetids, targetnames) {
	var str_id = '';
	var str_name = '';
	var str_name_div = '';
	if (obj != undefined ) {
		var row = 40;
		var color = 'black';
		for (var i = 0; i < obj.length; i++) {
			if (obj[i].selected) {
				
				var name = obj[i].text;
				var id = obj[i].value;
				str_id += id+' ';
				str_name += name+'\|';
				
				str_name_div += '<font color="'+color+'">'+ name+'</font>,';
				if (color == 'black') { color = 'black'; } else { color = 'black'; }
				
				if (str_name.length >= row) {
					str_name_div +=  '<br />';
					row += 60;
				}
			}
		}
	}
	
	var pos = str_name_div.lastIndexOf(',');
	str_name_div = str_name_div.substring(0, pos);
	document.getElementById(targetids).value = str_id;
	document.getElementById(targetnames).innerHTML = str_name_div;
	return false;
}

function nosession_handle(sender, arg) {
	var node = sender.getNode(arg.NodeId);
	var ids = node.getChildIds();
	if ( ids.length > 0 ) {
		childid = ids[0];
		if ( childid == 'nosession' ) {
			sender.removeNode(childid);
			if ( typeof sessionErrorMsg != 'undefined' && sessionErrorMsg != '' )
				errormsg = sessionErrorMsg;
			else
				errormsg = "Your session has timedout, you wil be redirected in 10 seconds";
			printErrorWindow(errormsg, 350, 250, true);
			return true;
		}
	}
	return true;
}

function delUnitItemNorefresh(url, msg, iwin) {
	var ret = confirm(msg);
	if ( ret ) {
		ajaxGetpage('', url, false);
	}
	parent.closeDhtmlWindow(iwin);
	return false;
}

function delUnitItem(url, stageurl, divid, msg) {
	var ret = confirm(msg);
	if ( ret ) {
		ajaxGetpage('', url, false);
		ajaxGetpage(divid, stageurl);
	}
	return false;
}

//Moved the calculation of window height and graph height here
//so we can get the accurate height even if the number of units changed.
function unitcalendar(url,title,width,divid,formname,chartdata,heighturl) {
	var add_bar_height = 30;
	var screen_offset = 110;
	var window_add = 45;
	var total = ajaxGetpage('', heighturl, false);
	if ( !isNaN(total) && total >= 0 && total < 100 ) {
		chartdata[3] = 55 + (total * add_bar_height);
		var window_height = chartdata[3] + window_add;
		if ( typeof screen != 'undefined' && typeof screen.availHeight != 'undefined' &&
				 screen.availHeight > 300 ) {
			if ( screen.availHeight-screen_offset-window_add < chartdata[3] ) {
				chartdata[3] = screen.availHeight-screen_offset-window_add;
				// dhtmlwindow code will reduce the height.
				window_height = screen.availHeight;
			}
		}
		if ( total == 0 ) {
			// For error window.
			width=600;
		}
		flashchart_window(url,title,width,window_height,divid,formname,chartdata);
	}
	return false;
}

//The new window resulted from clicking on a falshchart URL link.
//The parentid should be the id of the original flashchart id so we can hide it
//Ignore parentid or supply '' or false if you don't need to hide the parent flashchart window
function showChartUnitlist(url, title, width, height, id, parentid) {
	var hasParentid = ( typeof parentid != 'undefined' && parentid != '' && parentid != false );
	if ( hasParentid ) {
		hideDhtmlWindow(parentid);
	}
	var obj = newDhtmlWindow(url, title, width, height, id);
	//parentid is without the dhtml_ prefix
	//We hide parent window because Safari on Windows messes up the parent window
	//So, we hide parent window for all browsers
	if ( hasParentid ) {
		prepareDhxwinFlipDisplay(obj, parentid);
	}
}

//For mapping EQ
function ajax_select(obj , url, target_div , formname) {
	var str_id = '';
	if (obj != undefined ) {
		 if (obj=='1'){
			 str_id =obj;
		 }
		 else{
			 index  = obj.selectedIndex;
			str_id = obj.options[index].value;
		 }
	}
	if (str_id != '' && target_div != '' ) {
		document.getElementById(target_div).innerHTML = '<img src="'  + app_image_folder + 'ajax_arrow.gif' + '" />';
		ajaxPostform(target_div, url+str_id, formname, true);
	}
	return false;
}

function sortUnitItem(url, stageurl, divid) {
	if  (stageurl != undefined && stageurl != '') {
		ajaxGetpage('', url, false);
		ajaxGetpage(divid, stageurl, true);
	} else {
		ajaxGetpage(divid, url, false);
	}
	return false;
}


function select_listitem(obj, url, formname, update_div, type) {
	if (type=='') {
		type='0';
	}
	if (obj.name == 'filters') {
		updateContainer(update_div,  url + obj.value+'/'+type+'/'+update_div , formname);
	}
	else {
		updateContainer(update_div,  url  , formname);
	}
	return false;
}

function refresh_page(obj, url) {
	formname = 'resource_form';
	var rethtml = ajaxPostform('', url, formname, false);
	document.getElementById('dhtmlwin_resource').innerHTML = rethtml;
	return false;
}

// Used for showing or hiding the password based on selected auth type for the admin user popup.
// TODO: This will not work if a new auth plugin needs the password.
function showHidePasswordFields(obj, id) {
	if (typeof(obj.value) != undefined && isString(id)) {
		// 1 is the auth DB id for local.
		if ( obj.value == 1 ){
			showObj('#'+id);
		}
		else {
			hideObj('#'+id);
		}
	}
}

function refresh_select(obj,url,reset) {
	if (reset != '' || reset != undefined) {
		reset = '/'+reset;
	}
	else {
		reset = '';
	}
	ajaxGetpage('page_content', url+'/'+obj.value+reset, false);
	return false;
}

// Our ajaxPostform does not submit input type 'password' for security reason. Use this funciton to submit
// a form with password. Hidden fields are password and confirmpassword.
function submitUser(url, formname, stageurl, divid, dhtmlname) {
	var savepass = document.getElementById('password');
	var showpass = document.getElementById('showpass');
	var confirmpassword = document.getElementById('confirmpassword');
	var confirmpassword1 = document.getElementById('confirmpassword1');
	var oldpassword = document.getElementById('oldpassword');
	var oldpassword1 = document.getElementById('oldpassword1');
	
	if ( isObject(oldpassword) && isObject(oldpassword1) && isString(oldpassword1.value) ) {
		oldpassword.value = des_encrypt(oldpassword1.value);
	}
	savepass.value = des_encrypt(showpass.value);
	confirmpassword.value = des_encrypt(confirmpassword1.value);
	submitDhtml(url, formname, stageurl, divid, dhtmlname);
	return false;
}
/*
function showbutton(obj,id) {
	
	var style_show = 'block';
	var style_hide = 'none';
	if (obj.value != undefined) {
	var object = document.getElementById(id);
			if (obj.value != ''){
				object.style.disabled=true;
				object.style.display = style_show;
			}else{
				object.style.display = style_hide;
			}
		}
}
*/
/*
function show_select_local(obj, targetids, targetnames) {
	var str_id = '';
	var str_name = '';
	var str_name_div = '';
	if (obj != undefined ) {
		var row = 40;
		var color = 'red';
		for (var i = 0; i < obj.length; i++) {
			if (obj[i].selected) {
				
				var name = obj[i].text;
				var id = obj[i].value;
				str_id += id+' ';
				str_name += name+'\|';
				
				str_name_div += '<font color="'+color+'">'+ name+'</font>,';
				if (color == 'red') { color = 'red'; } else { color = 'red'; }
				
				if (str_name.length >= row) {
					str_name_div +=  '<br />';
					row += 60;
				}
			}
		}
	}

	var pos = str_name_div.lastIndexOf(',');
	str_name_div = str_name_div.substring(0, pos);
	//document.getElementById(targetids).value = str_id;
	alert(str_name_div);
	document.getElementById(targetnames).innerHTML = str_name_div;
	return false;
}
*/

function refresh_unitcopy(url,courseid) {
	formname = 'resource_form';
	var rethtml = ajaxPostform('', url, formname, false);
	document.getElementById('dhtmlwin_resource').innerHTML = rethtml;
	refresh_menutree();
	return false;
}

/*
function showhide_course_unit(showflag, hidebutton, showbutton ,url ) {
	formname = 'resource_form';
	ajaxPostform('', url, formname, false);
	display(showflag, hidebutton, showbutton, '' ) ;
	return false;
}
*/

//For admin section, searches using the user input search text
//function search_filter(url,starturl,formname,div) {
function search_filter(url,formname,div) {
	updateContainer(div, url, formname);
	return false;
}

function getRadioButton(objid, divid, courseids, post_url, formname, back_url) {
	var obj = document.getElementsByName(objid);
	if (obj != undefined) {
		for( var i = 0; i < obj.length; i++ ) {
			if (obj[i].checked == true) {
				if (obj[i].alt == '') {
					closeDhtmlWindow(divid);
					return false;
				}
				else if (confirm(obj[i].alt)) {
					var rethtml = ajaxPostform('', post_url, formname, false);
					if (rethtml == ajaxSuccess ) {
						parent.closeDhtmlWindow(divid);
						parent.refresh_menutree();
						parent.ajaxGetpage('page_content', back_url, true);
						return true;
					}
				}
			}
		}
	}
}

function del_listitem(url, divid, msg,formname) {
	if ( confirm(msg) ) {
		if (divid == 'page_content') {
			ajaxGetpage(divid, url, false);
		}else{
			var rethtml = ajaxPostform('', url, formname, false);
			updateWindow(rethtml, formname, '', divid);
		}
	}
	return false;
}

function compare_histoty(url, formname, update_div) {
	updateWindow(url, formname, '', update_div);
	return false;
}

function histoty_version(href,url,formname,title, width, height, div) {
	var rethtml = ajaxPostform('', href, formname, false);
	if(rethtml!=false){
		newDhtmlWindow(url+rethtml,title, width, height, div);
	}
return false;
}

function change_button(divid, imagesrc, title, urlclick, formname, update_div) {
	if (title == undefined || title == '') {
		title = '';
	}
	var htmlimg = "<img src='"+imagesrc+"' title='"+title+"' border='0' />";
	if (update_div == undefined)
		update_div = "page_content";
	if (urlclick !== undefined && urlclick !== ''  && urlclick !== null) {
		var onclick = 'ajaxPostform("'+update_div+'", "'+urlclick+'", "'+formname+'",false); return false;';
		htmlimg = "<a href='"+urlclick+"' onClick='"+onclick+" ' >"+htmlimg+"</a>";
	}
	var obj = document.getElementById(divid);
	if (obj != undefined) {
		obj.innerHTML = htmlimg;
	}
	return false;
}

//function user_course(href_save, href_refresh, href_desc, formname,descid) {
function user_course(href_save, href_refresh, formname) {
	var rethtml = ajaxPostform('', href_save, 'resource_form', false);
	if (rethtml == ajaxSuccess) {
		updateWindow(href_refresh, formname, 'title', 'course_input');
	}
	return false;
}

function course_editor(href_save, href_refresh, href_desc, formname,descid) {
	ajaxPostform('', href_save, 'resource_form', false);
	// Always refresh even fails.
	ajaxGetpage("page_content", href_desc, true);
	updateWindow(href_refresh, formname, 'title', 'course_input');
	return false;
}

/*
function unlock_editorunit(url,url_unlock,courseid,divbutton) {
	ajaxGetpage('page_content',url, false);
	ajaxPostform('', url_unlock, 'resource_form', false)
    refresh_unitnode(courseid);
	var style_hide = 'none';
	var obj = document.getElementById(divbutton);
	if (obj != undefined )
		obj.style.display = style_hide;

    return false;
}
*/

function update_checkbox(href_save,value) {
	ajaxPostform('', href_save, 'itstd_form', true);
}

function course_lnk(divid, imagesrc, title, urlclick, formname) {
	if ( !isString(title) ) {
		title = '';
	}
	htmlimg = "<img src='"+imagesrc+"' title='"+title+"' border='0' />";
	if (urlclick != undefined && urlclick != '') {
		updateWindow(urlclick,formname, "title","course_input");
		htmlimg = "<a href='"+urlclick+"' onClick='"+onclick+"' >"+htmlimg+"</a>";
	}
	return false;
}

function user_goal(href_save, href_refresh, href_goal, formname,divname) {
	var rethtml = ajaxPostform('', href_save, formname, false);
	if (rethtml == ajaxSuccess) {
		ajaxGetpage("page_content", href_goal, true);
		updateWindow(href_refresh, formname, 'title', divname);
	}
	return false;
}

function select_unit(url, formname, update_div, massage) {
	ajaxPostform(update_div,  url , formname, true);
	delayDivUpdate('massage', '&nbsp;');
	return false;
}

function select_item_goal(obj, url, formname, update_div) {
	ajaxPostform(update_div,  url + obj.value , formname, true);
	return false;
}

function add_goal(url,href_refresh,formname, massge) {
	var rethtml = ajaxPostform("page_content", url, formname, false);
	if (rethtml == true) {
		var obj = document.getElementById('massage');
		if (obj != undefined) {
			obj.innerHTML = massge;
		}
		delayDivUpdate('massage', '&nbsp;');
	}
	else{
		var obj = document.getElementById('title');
		var obj_input = document.getElementById('txttitle');
		if (obj != undefined && obj_input != undefined) {
			obj_input.value = obj.value;
		}
		else {
			//alert('object lost'); //please change text
		}
	}
	return false;
}

function update_datetime(url,formname) {
	ajaxPostform('',  url , formname, true);
	return false;
}

// TODO: Enhance this.
function delayDivUpdate(divid, message, timeout){
	var obj = document.getElementById(divid);
	if (obj != undefined) {
		if (timeout == undefined) {
			var func_name = 'delayDivUpdate("'+divid+'","'+message+'",true);';
			setTimeout(func_name,5000);
		}
		else {
			obj.innerHTML = '&nbsp;';
		}
	}
}

function totalunit_refresh() {
	ajaxGetpage('total_unit', appHomeUrl+'menu/menu/totalunit', true);
}

function find_filter(url, formname, update_div, type) {
	ajaxPostform(update_div,  url , formname, true);
	return false;
}

function update_radio(radio_obj, url) {
	var ret_code;
	ret_code = ajaxGetpage('', url, false);
	if ( ret_code != ajaxSuccess ) {
		alert(raido_update_error_msg);
		if ( isObject(radio_obj) && typeof(radio_obj.checked) !== 'undefined' ) {
			// All non-IE browsers need this. IE deselects for you automatically.
			radio_obj.checked = false;
		}
		return false;
	}
	return true;
}

function survey_done(url, homeurl, formname, success_msg, failed_msg, incomplete_msg) {
	var ret_code='';
	if ( !checked_all_radios(formname) ) {
		alert(incomplete_msg);
		return false;
	}
	ret_code = ajaxGetpage('', url, false);
	if ( ret_code == ajaxSuccess ) {
		alert(success_msg);
	}
	else {
		alert(failed_msg);
	}
	window.location = homeurl;
	return false;
}

function survey_result(url,width,height) {
	ajaxPostform('page_content', url, 'surveyresult', false);
	var index_text = ajaxGetpage('', appHomeUrl+'survey/result/chartindexes', false);
	var waittime = 0;
	if ( index_text.length > 1 ) {
		var indexes = eval(index_text);
		for (var i in indexes) {
			//Flash object is async so use settimeout to slow down server requests
			var chartfunction = 'print_flashchart("' + appIncludePath + 'flashchart.swf","surveychart_' +
				indexes[i] + '",' + width + ',' + height + ',"' + appHomeUrl +
				'survey/result/chart/' + indexes[i] + '");';
			var chartfunction_teacher = 'print_flashchart("' + appIncludePath + 'flashchart.swf","surveychart_' +
				indexes[i] + 't",' + width + ',' + height + ',"' + appHomeUrl +
				'survey/result/chart/' + indexes[i] + 't");';
			//Some timing issue with browser and flash
			if ( waittime == 0 ) {
				setTimeout(chartfunction, 50);
				setTimeout(chartfunction_teacher, 1600);
				waittime=2600;
			}
			else {
				waittime += 400;
				setTimeout(chartfunction, waittime);
				waittime += 400;
				setTimeout(chartfunction_teacher, waittime);
			}
		}
	}
	return false;
}

function confirmDBUpgrade(url,title,width,height,divid,msg) {
	var ret = confirm(msg);
	if ( ret ) {
		openBrowserWindow(url,width,height,divid,true);
	}
	return false;
}

//Course selection window for read-only teachers in the admin user page
function course_read(id,enable) {
	var url = appHomeUrl + 'admin/course/select/' + id + '/0/' + enable + '/user';
	new newDhtmlWindow(url, ' ', 600, 470, 'course_input');
	return false;
}

function course_edit(id,enable) {
	var url = appHomeUrl + 'admin/course/select/' + id + '/1/' + enable + '/user';
	new newDhtmlWindow(url, ' ', 600, 470, 'course_input');
	return false;
}

function get_selectbox_val(name){
	if (!name) {
		return false;
	}
	var element_id = document.getElementById(name);
	if (!element_id){
		return false;
	}
	// get value from selected index
	return element_id.options[element_id.selectedIndex].value;
}

function set_textarea_properties(cols, rows){
	var textarea_obj = document.getElementById('text1');
	var window_size = window_size_array();
	if ( !isObject(textarea_obj) || !isObject(window_size) ) {
		return false;
	}
	if ( !isNaN(cols) && cols > 0 ){
		window_width = window_size.width;
		max_cols = parseInt(window_width/cols, 10);
		cur_cols = textarea_obj.cols;
		if ( max_cols>5 && !isNaN(cur_cols) && cur_cols > max_cols ) {
			textarea_obj.cols = max_cols;
		}
	}
	if ( isInteger(rows) ){
		textarea_obj.rows = rows;
	}
	return false;
}

function admin_cleanup(buttonid, winname, url) {
	disable_button(buttonid);
	openBrowserWindow(url, 500, 250, 'admincleanup', true);
	return false;
}

function mapping_window(url,title,width,height,divid,formname,chartdata) {
	if ( isArray(chartdata) ) {
		flashchart_window(url,title,width,height,divid,formname,chartdata);
		return false;
	}
	var rethtml=ajaxPostform('', url, formname, false);
	if ( isString(rethtml) ) {
		newDhtmlWindow_text(title, width, height, divid, rethtml);
	}
	return false;
}
