<?php
/**
 * admin_loadconfig - Load configurations
 *
 * @author $Author: dtong $
 * @version $Id: admin_loadconfig.php,v 1.17 2012/05/17 09:16:39 dtong Exp $
 * @copyright Copyright (c) 2011, Tiller Software Co., Ltd.
*/

require_once 'config_data.php';

class admin_loadconfig {
	// Add more functions as necessary
	// private static $run_functions = array('timezone');
	private $CI;
	private $config = array();

	function __construct($init=TRUE) {
		$this->CI = &get_instance();
		if ( $init === TRUE ) {
			$this->load_config(config_data::SYSTEM_GENERAL, FALSE, FALSE);
			// The load_config above will load all configs and no need for the following.
			// Try to have less overhead for the system.
			/*$this->load_config(config_data::SITE_TEMPLATE, FALSE, FALSE);
			if ( osa_3p_available() ) {
				$this->load_config(CMS_3P_ADMIN_CONFIG_INDEX, FALSE, FALSE);
			}*/
			//Use one merge for all configs above for faster performance.
			//This gets call on every request so it has to be efficient.
			$this->merge_config();
			//Run other startup functions
			// $this->run();
			$this->timezone();
		}
	}

	// DO NOT USE THIS FUNCTION.
	// Use this only if you need to reread the DB and make sure to get the latest DB value.
	// Always use $CI->config->item() instead. This was done for the scheduler.
	function get_value($name) {
		if ( isset($this->config[$name]) ) {
			return $this->config[$name];
		}
		return NULL;
	}

	// Load a config. If $reset_db_values is true then it reads from DB again.
	// If $merge_config is true then loads the DB values to the current CI config.
	function load_config($index, $reset_db_values=TRUE, $merge_config=TRUE) {
		static $db_values = NULL;

		$this->CI->load->model('admin/config_model');
		if ( $db_values === NULL || $reset_db_values ) {
			$tmp_index = $index;
			if ( !$reset_db_values ) {
				//This means we are not resetting and we should ignore the $index
				$tmp_index = FALSE;
			}
			//We only get all the app configs once if $reset_db_values is set to false
			//regardless how many config systems we deal with.
			$db_values = &$this->CI->config_model->get_allconfig($tmp_index);
		}

		if ( !empty($db_values) ) {
			//get_config() won't obtain the language text but it is not necessary here.
			//the admin menu can call get_config() again and the language text will be available.
			$configdata_withhash = & config_data::get_config($index, TRUE);

			$config = array();
			$array_keys = array_keys($db_values);
			// foreach ($db_values as $key=>$record) {
			foreach ($array_keys as $key) {
				$record = &$db_values[$key];
				// Always load everything. Done for performance reason.
				// if ( $record->system == $index ) {
				if ( isset($configdata_withhash[$key]) &&
					  $configdata_withhash[$key][config_data::INDEX_TYPE] == config_data::TYPE_LONGSTRING ) {
					$record->value = html_entity_decode($record->value);
				}
				$this->config[$key] = &$record->value;
				// }
			}

			if ( $merge_config ) {
				$this->merge_config();
			}
		}
	}

	//Should be faster to use merge insted of calling set_item() on every config element
	//If CI chnages CI->config->config to private then this code needs to be changed
	private function merge_config() {
		if ( count($this->config) > 0 ) {
			$this->CI->config->config = array_merge($this->CI->config->config, $this->config);
			$this->config = array();
		}
	}
/*
	//Main function to run all functions defined in class variable $run_functions
	private function run() {
		foreach (self::$run_functions as $function) {
			$this->$function();
		}
	}
*/
	//Set the time zone if it is defined.
	private function timezone() {
		$zone = $this->CI->config->item('cms_timezone');
		if ( !empty($zone) ) {
			date_default_timezone_set($zone);
		}
		else {
			//Just to get rid of the annoying PHP warning message starting from 5.3
			//Could ask the user to enter the time zone during installation later
			//date_default_timezone_get() always returns a valid timezone string but just in case
			$zone = @date_default_timezone_get();
			if ( empty($zone) || $zone == 'UTC' ) {
				//Hometown is Boston! Go Celtics, Red Sox and Patriots!
				$zone = 'America/New_York';
			}
			@date_default_timezone_set($zone);
		}
	}
}