<?php
/**
 * cmsupgradebase.php
 *
 * The base class for upgrade pre-SQL and post-SQL PHP files. If a pre or post file needs to use a sql file then named the sql file
 * with .sqlx extension (e.g. 1.1.2_pre.sqlx) so it won't confuse the upgrade system. All child classes have to
 * start the upgrade process in the constructor. How the code is written inside the child classes is not restricted
 * since they are totally isoltaed from the caller. This design ensures no conflicts can happen between
 * upgrades and systems.
 *
 * Examples:
 *
 * 	For TODCM main upgrade:
 * 	1.2.1_pre.php - class upgrade_1_2_1_pre
 * 	1.2.1_pre.sqlx (optional)
 * 	1.2.1_post.php - class upgrade_1_2_1_post
 * 	1.2.1_post.sqlx (optional)
 *
 * 	For 3rd party application "test":
 * 	1.2.1_pre.php - class upgrade_test_1_2_1_pre
 * 	1.2.1_pre.sqlx (optional)
 * 	1.2.1_post.php - class upgrade_test_1_2_1_post
 * 	1.2.1_post.sqlx (optional)
 *
 * Note: The .sql file is required else the pre and post PHP files will not get processed.
 * 		You would need an empty .sql file if there is no SQL staements but needs PHP processing.
 *
 * @author $Author: dtong $
 * @version $Id: cmsupgradebase.php,v 1.1 2011/11/21 10:24:20 dtong Exp $
 * @copyright Copyright (c) 2011, Tiller Software Co., Ltd.
*/
if ( ! defined('BASEPATH')) exit('No direct script access allowed');

class cmsupgradebase {
	// Use this to tell the caller an error has occured. This is entended to not get text from a language file.
	// All error messages will be hard-coded in English. Only admin users will see these messages.
	public $error_msg = FALSE;

	function __construct() {
		// Right now this is empty, but the child classes have to call this in their constructor.
	}
}